/**
 * @file      canvas_fitsio.h
 * @brief     FITS IO support for canvas.
 * @date      2010-02-24
 *
 * @copyright
 * Copyright 2010 Japan Aerospace Exploration Agency
 *
 */

#ifndef _CANVAS_FITSIO_H
#define _CANVAS_FITSIO_H

#include <fitsio.h>
#include "canvas.h"

/*
 * FITS のカラーフォーマット
 * cv_write_fits の attr で指定します。
 */
#define CVFormatFitsImageExtension   0x01000000  /** Image Extension フォーマット */
#define CVFormatFitsCube             0x02000000  /** RGBCube フォーマット */

typedef int (*canvasFitsioAfterCreateImageCallback)(canvas *cv, fitsfile *fits, void *userdata);

__BEGIN_DECLS
/* コンストラクタ：FITS 読み込み。
 * attr はマスク値です。
 * - CVFormatBottomUp  画像データをボトムアップフォーマットとして処理します。
 */
canvas *cv_load_fits(const char *path, int attr);

/* canvas データを FITS 形式で保存します。
 * attr はマスク値です。
 * - CVFormatBottomUp  FITS 保存形式にボトムアップフォーマットを使用します。
 */
int cv_save_fits(canvas *self, const char *path, int attr,
                 canvasFitsioAfterCreateImageCallback cb, void *userdata);

/* canvas データを fitsfile オブジェクトに書きだします。
 * fits の形式は以下のようになっている必要があります。
 * - naxis = 2
 * - naxes[0] >= width
 * - naxes[1] >= height
 * 詳しくは cfitsio のマニュアルを参照してください。
 * attr はマスク値です。
 * - CVFormatBottomUp  FITS 保存形式にボトムアップフォーマットを使用します。
 */
int cv_write_fits(canvas *self, fitsfile *fits, int attr,
                  canvasFitsioAfterCreateImageCallback cb, void *userdata);

__END_DECLS

#endif // _CANVAS_FITSIO_H
