/**
 * @file      canvas_pngio.h
 * @brief     PNG IO support for canvas.
 * @date      2010-05-26
 *
 * @copyright
 * Copyright 2010 AstroArts Inc.
 *
 */

#ifndef _CANVAS_PNGIO_H
#define _CANVAS_PNGIO_H

#include <png.h>
#include "canvas.h"

__BEGIN_DECLS
/**
 * コンストラクタ：PNG 読み込み。
 * @param path  入力ファイルパス。
 * @result  canvas instance. you must call canvas_free() at done.
 */
canvas *cv_load_png(const char *path);

/**
 * コンストラクタ：PNG 読み込み (stream 版)。
 * @param io  FILE stream.
 * @result  canvas instance. you must call canvas_free() at done.
 */
canvas *cv_load_png_with_std(FILE *io);

/**
 * コンストラクタ：PNG 読み込み (メモリ版)。
 * @param ptr   メモリの先頭アドレス。
 * @param size  データサイズ。
 * @result  canvas instance. you must call canvas_free() at done.
 */
canvas *cv_load_png_with_bytes(const void *ptr, size_t size);

/**
 * canvas データを PNG 形式で保存します。
 * @param self        canvas instance.
 * @param path        出力ファイルパス。
 * @param compression 圧縮レベル。[1-9]
 * @result  1: success. 0: error.
 */
int cv_save_png(canvas *self, const char *path, int compression);

/**
 * canvas データを PNG 形式で保存します。
 * @param self        canvas instance.
 * @param io          FILE ストリーム。
 *                    wb で open してある必要があります。
 * @param compression 圧縮レベル。[1-9]
 * @result  1: success. 0: error.
 */
int cv_save_png_with_std(canvas *self, FILE *io, int compression);

__END_DECLS

#endif // _CANVAS_PNGIO_H
