/**
 * @file      render.h
 * @brief     flow_ig rendering functions
 * @date      2011-03-11
 *
 * @copyright
 * Copyright 2011 Japan Aerospace Exploration Agency
 *
 */

#ifndef _RENDER_H_
#define _RENDER_H_

#include <stdio.h>
#include "flowig_config.h"
#include "sv_doc.h"
#include "canvas.h"

#define RENDER_NO_ERROR                       0
#define RENDER_ILLEGAL_PROJECTION_Z           1
#define RENDER_SHAPE_MODEL_LOAD_ERROR         2
#define RENDER_MEMORY_FULL                    3
#define RENDER_WMS_CACHE_OPEN_ERROR           4
#define RENDER_WMS_GET_CAPABILITY_ERROR       5
#define RENDER_WMS_PARSE_CAPABILITY_ERROR     6
#define RENDER_WMS_PNG_UNSUPPORT_ERROR        7
#define RENDER_WMS_LAYER_NOT_FOUND_ERROR      8
#define RENDER_WMS_KNOWN_CRS_NOT_FOUND_ERROR  9
#define RENDER_WMS_GET_IMAGE_ERROR           10
#define RENDER_IMAGE_FORMAT_ERROR            11
#define RENDER_LOAD_IMAGE_ERROR              12

#define SIZE_STAR_TEX 8

typedef struct _render {
  const char *app_name;
  FLOWIGConfig *config;
  SV_FRAME *frame;
  canvas *canvas;
  canvas *star_tex[SIZE_STAR_TEX];
  enum FLOWProjectionMode projection_mode;
  int error_code;
} render;

__BEGIN_DECLS
/**
 * render 構造体を初期化します。
 */
void render_init(render *self, const char *app_name, FLOWIGConfig *config, SV_FRAME *frame, canvas *cv, enum FLOWProjectionMode mode);

/**
 * render 構造体で使っているメモリを開放します。
 */
void render_free(render *self);

FLOWIGConfig *render_config(render *self);
const char *render_app_name(render *self);
SV_FRAME *render_frame(render *self);
canvas *render_canvas(render *self);
canvas *render_star_tex(render *self, int magidx);

/**
 * レンダリングメイン。
 */
BOOL render_image(render *self);

const char *render_get_message(render *self);

/**
 * デバッグ用画像レンダリング。
 */
BOOL render_lookdown_image(render *self);

/**
 * path から画像を読み込み、canvas を返します。
 * canvas は利用が終わったら開放してください。
 * @param config  アプリ設定。
 * @param path    ファイルパス。
 */
canvas *load_image(FLOWIGConfig *config, const char *path);

__END_DECLS

#endif /* _RENDER_H_ */
